==> ejc-gdjgtask-impl-3.0.0-20211011.040445-14-sources.jar: com/ejianc/business/service/IWorkService.java <==
package com.ejianc.business.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.bean.WorkEntity;
import com.ejinac.business.vo.WorkAssignVO;
import com.ejinac.business.vo.WorkHistoryVO;
import com.ejinac.business.vo.WorkVO;

import java.util.List;

/**
 * 工作
 * 
 * @author generator
 * 
 */
public interface IWorkService extends IBaseService<WorkEntity> {
    /**
     * 查询数量
     * @param userId
     * @return
     */
    public  CommonResponse<JSONObject> countNumber(Long userId);

    /**
     * 查询我的工作
     * @param queryParam
     * @return
     */
    public IPage<WorkEntity> queryMyList(QueryParam queryParam);

    /**
     * 指派
     * @param workAssignVO
     * @return
     */
    public CommonResponse<String> assignTask(List<WorkAssignVO> workAssignVO);

    /**
     * 处理
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> dealTask(WorkHistoryVO workHistoryVO);

    /**
     * 关闭
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> closeTask(WorkHistoryVO workHistoryVO);

    /**
     * 查询详情
     * @param id
     * @return
     */
    public WorkVO queryDetail(Long id);

    /**
     * 评论
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> commentTask(WorkHistoryVO workHistoryVO);

    /**
     * 根据uuid查询一条数据
     * @param threadUuid
     * @return
     */
    public WorkEntity getByThreadUuid(String threadUuid);

    public CommonResponse<String> pollingTask();
}

==> ejc-gdjgtask-impl-3.0.0-20220906.083925-78-sources.jar: com/ejianc/business/service/IWorkService.java <==
package com.ejianc.business.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;
import com.ejianc.business.bean.WorkEntity;
import com.ejinac.business.vo.WorkAssignVO;
import com.ejinac.business.vo.WorkHistoryVO;
import com.ejinac.business.vo.WorkStateVO;
import com.ejinac.business.vo.WorkVO;

import java.util.List;

/**
 * 工作
 * 
 * @author generator
 * 
 */
public interface IWorkService extends IBaseService<WorkEntity> {
    /**
     * 查询数量
     * @param userId
     * @return
     */
    public  CommonResponse<JSONObject> countNumber(Long userId);

    /**
     * 查询我的工作
     * @param queryParam
     * @return
     */
    public IPage<WorkEntity> queryMyList(QueryParam queryParam);

    /**
     * 指派
     * @param workAssignVO
     * @return
     */
    public CommonResponse<String> assignTask(List<WorkAssignVO> workAssignVO);

    /**
     * 处理
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> dealTask(WorkHistoryVO workHistoryVO);

    /**
     * 关闭
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> closeTask(WorkHistoryVO workHistoryVO);

    /**
     * 查询详情
     * @param id
     * @return
     */
    public WorkVO queryDetail(Long id);

    /**
     * 评论
     * @param workHistoryVO
     * @return
     */
    public CommonResponse<String> commentTask(WorkHistoryVO workHistoryVO);

    /**
     * 根据uuid查询一条数据
     * @param threadUuid
     * @return
     */
    public WorkEntity getByThreadUuid(String threadUuid);

    public CommonResponse<String> pollingTask();

    /**
     * 提醒用户
     * @return
     */
    public CommonResponse<String> warningMessage();

    /**
     * 发送给责任人
     * @param workEntity
     */
    public void sendResponsibleUserMessage(WorkEntity workEntity);

    /**
     * 发送指定工作
     * @param workId
     * @return
     */
    public CommonResponse<String> warningSendMessage(Long workId);

    public WorkStateVO queryStateAll(Integer taskLevel);

    List<WorkVO> queryWorkList(Page<WorkVO> page, QueryWrapper wrapper, List<Long> orgIds,Long deptId);

    void delByTaskIdAndDetailIds(List<Long> delDetailIds, Long id);
}
